Bookmark class used to bookmark and restore application state.
bookmark()Bookmark$bookmark(state)
restore()Bookmark$restore(state)
clone()The objects of this class are cloneable with this method.
Bookmark$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.